@@ -358,13 +358,13 @@ class StateArray(State):
         return self['mask']
 
     def __getitem__(self, key):
-        if isinstance(key, slice):
+        if isinstance(key, slice) or isinstance(key, int):
             shape = self['mask'][key].shape
+            if len(shape) == 0:
+                return State({k: v[key] for (k, v) in self.items()}, device=self.device)
             return StateArray({k: v[key] for (k, v) in self.items()}, shape, device=self.device)
-        if isinstance(key, int):
-            return State({k: v[key] for (k, v) in self.items()}, device=self.device)
         if torch.is_tensor(key):
-            # some things may get los
+            # some things may get lost
             d = {}
             shape = self['mask'][key].shape
             for (k, v) in self.items():
@@ -387,6 +387,41 @@ class StateArray(State):
     def __len__(self):
         return self.shape[0]
 
+    @classmethod
+    def cat(cls, state_array_list, axis=0):
+        '''Concatenates along batch dimention'''
+        if len(state_array_list) == 0:
+            raise ValueError("cat accepts a non-zero size list of StateArrays")
+
+        d = {}
+        state_size = sum(state_array.shape[axis] for state_array in state_array_list)
+        new_shape = list(state_array_list[0].shape)
+        new_shape[axis] = state_size
+        new_shape = tuple(new_shape)
+        keys = list(state_array_list[0].keys())
+        for key in keys:
+            d[key] = torch.cat([state_array[key] for state_array in state_array_list], axis=axis)
+        return StateArray(d, new_shape, device=state_array_list[0].device)
+
+    def batch_execute(self, minibatch_size, fn):
+        '''
+        execute in batches to reduce memory consumption
+        '''
+        data = self
+        batch_size = self.shape[0]
+        results = []
+        last = 0
+        while last < batch_size:
+            # load the indexes for the minibatch
+            first = last
+            last = min(first + minibatch_size, batch_size)
+            results.append(fn(data[first:last]))
+
+        if isinstance(results[0], StateArray):
+            return StateArray.cat(results)
+        else:
+            return torch.cat(results, axis=0)
+
 
 class MultiagentState(State):
     def __init__(self, x, device='cpu', **kwargs):
