@@ -8,10 +8,6 @@ class GymEnvironmentTest(unittest.TestCase):
         env = GymEnvironment('CartPole-v0')
         self.assertEqual(env.name, 'CartPole-v0')
 
-    def test_preconstructed_env_name(self):
-        env = GymEnvironment(gym.make('Blackjack-v0'))
-        self.assertEqual(env.name, 'BlackjackEnv')
-
     def test_reset(self):
         env = GymEnvironment('CartPole-v0')
         state = env.reset()
@@ -20,14 +16,6 @@ class GymEnvironmentTest(unittest.TestCase):
         self.assertFalse(state.done)
         self.assertEqual(state.mask, 1)
 
-    def test_reset_preconstructed_env(self):
-        env = GymEnvironment(gym.make('CartPole-v0'))
-        state = env.reset()
-        self.assertEqual(state.observation.shape, (4,))
-        self.assertEqual(state.reward, 0)
-        self.assertFalse(state.done)
-        self.assertEqual(state.mask, 1)
-
     def test_step(self):
         env = GymEnvironment('CartPole-v0')
         env.reset()
