@@ -2,12 +2,9 @@
 import torch
 import time
 import numpy as np
-from all.core import State
-from .writer import ExperimentWriter, CometWriter
+from all.logging import ExperimentLogger, CometLogger
 from .experiment import Experiment
 from all.environments import VectorEnvironment
-from all.agents import ParallelAgent
-import gym
 
 
 class ParallelEnvExperiment(Experiment):
@@ -22,11 +19,11 @@ class ParallelEnvExperiment(Experiment):
             logdir='runs',
             quiet=False,
             render=False,
-            write_loss=True,
-            writer="tensorboard"
+            verbose=True,
+            logger="tensorboard"
     ):
         self._name = name if name is not None else preset.name
-        super().__init__(self._make_writer(logdir, self._name, env.name, write_loss, writer), quiet)
+        super().__init__(self._make_logger(logdir, self._name, env.name, verbose, logger), quiet)
         self._n_envs = preset.n_envs
         if isinstance(env, VectorEnvironment):
             assert self._n_envs == env.num_envs
@@ -34,7 +31,7 @@ class ParallelEnvExperiment(Experiment):
         else:
             self._env = env.duplicate(self._n_envs)
         self._preset = preset
-        self._agent = preset.agent(writer=self._writer, train_steps=train_steps)
+        self._agent = preset.agent(logger=self._logger, train_steps=train_steps)
         self._render = render
 
         # training state
@@ -124,7 +121,7 @@ class ParallelEnvExperiment(Experiment):
     def _done(self, frames, episodes):
         return self._frame > frames or self._episode > episodes
 
-    def _make_writer(self, logdir, agent_name, env_name, write_loss, writer):
-        if writer == "comet":
-            return CometWriter(self, agent_name, env_name, loss=write_loss, logdir=logdir)
-        return ExperimentWriter(self, agent_name, env_name, loss=write_loss, logdir=logdir)
+    def _make_logger(self, logdir, agent_name, env_name, verbose, logger):
+        if logger == "comet":
+            return CometLogger(self, agent_name, env_name, verbose=verbose, logdir=logdir)
+        return ExperimentLogger(self, agent_name, env_name, verbose=verbose, logdir=logdir)
