@@ -11,8 +11,8 @@ def run_experiment(
         quiet=False,
         render=False,
         test_episodes=100,
-        write_loss=True,
-        writer="tensorboard"
+        verbose=True,
+        logger="tensorboard"
 ):
     if not isinstance(agents, list):
         agents = [agents]
@@ -31,8 +31,8 @@ def run_experiment(
                 logdir=logdir,
                 quiet=quiet,
                 render=render,
-                write_loss=write_loss,
-                writer=writer
+                verbose=verbose,
+                logger=logger
             )
             experiment.train(frames=frames)
             experiment.save()
