@@ -1,5 +1,5 @@
 from .gaussian import GaussianPolicy
-from .greedy import GreedyPolicy
+from .greedy import GreedyPolicy, ParallelGreedyPolicy
 from .softmax import SoftmaxPolicy
 from .deterministic import DeterministicPolicy
 from .soft_deterministic import SoftDeterministicPolicy
@@ -7,6 +7,7 @@ from .soft_deterministic import SoftDeterministicPolicy
 __all__ = [
     "GaussianPolicy",
     "GreedyPolicy",
+    "ParallelGreedyPolicy",
     "SoftmaxPolicy",
     "DeterministicPolicy",
     "SoftDeterministicPolicy"
