@@ -2,7 +2,7 @@ import os
 import unittest
 import torch
 from all.environments import GymEnvironment, DuplicateEnvironment
-from all.logging import DummyWriter
+from all.logging import DummyLogger
 from all.presets import Preset, ParallelPreset
 from all.presets.classic_control import (
     a2c,
@@ -67,7 +67,7 @@ class TestClassicControlPresets(unittest.TestCase):
 
     def validate_standard_preset(self, preset):
         # train agent
-        agent = preset.agent(writer=DummyWriter(), train_steps=100000)
+        agent = preset.agent(logger=DummyLogger(), train_steps=100000)
         agent.act(self.env.state)
         # test agent
         test_agent = preset.test_agent()
@@ -80,7 +80,7 @@ class TestClassicControlPresets(unittest.TestCase):
 
     def validate_parallel_preset(self, preset):
         # train agent
-        agent = preset.agent(writer=DummyWriter(), train_steps=100000)
+        agent = preset.agent(logger=DummyLogger(), train_steps=100000)
         agent.act(self.parallel_env.state_array)
         # test agent
         test_agent = preset.test_agent()
