@@ -4,7 +4,7 @@ from torch.optim.lr_scheduler import CosineAnnealingLR
 from all.agents import PPO, PPOTestAgent
 from all.approximation import VNetwork, FeatureNetwork, Identity
 from all.bodies import TimeFeature
-from all.logging import DummyWriter
+from all.logging import DummyLogger
 from all.optim import LinearScheduler
 from all.policies import GaussianPolicy
 from all.presets.builder import ParallelPresetBuilder
@@ -72,7 +72,7 @@ class PPOContinuousPreset(ParallelPreset):
         self.policy_model = hyperparameters["policy_model_constructor"](env).to(device)
         self.action_space = env.action_space
 
-    def agent(self, writer=DummyWriter(), train_steps=float('inf')):
+    def agent(self, logger=DummyLogger(), train_steps=float('inf')):
         n_updates = train_steps * self.hyperparameters['epochs'] * self.hyperparameters['minibatches'] / (self.hyperparameters['n_steps'] * self.hyperparameters['n_envs'])
 
         value_optimizer = Adam(self.value_model.parameters(), lr=self.hyperparameters['lr'], eps=self.hyperparameters['eps'])
@@ -85,7 +85,7 @@ class PPOContinuousPreset(ParallelPreset):
             value_optimizer,
             loss_scaling=self.hyperparameters['value_loss_scaling'],
             clip_grad=self.hyperparameters['clip_grad'],
-            writer=writer,
+            logger=logger,
             scheduler=CosineAnnealingLR(
                 value_optimizer,
                 n_updates
@@ -97,7 +97,7 @@ class PPOContinuousPreset(ParallelPreset):
             policy_optimizer,
             self.action_space,
             clip_grad=self.hyperparameters['clip_grad'],
-            writer=writer,
+            logger=logger,
             scheduler=CosineAnnealingLR(
                 policy_optimizer,
                 n_updates
@@ -114,7 +114,7 @@ class PPOContinuousPreset(ParallelPreset):
                 0,
                 n_updates,
                 name='clip',
-                writer=writer
+                logger=logger
             ),
             epochs=self.hyperparameters['epochs'],
             minibatches=self.hyperparameters['minibatches'],
@@ -123,7 +123,7 @@ class PPOContinuousPreset(ParallelPreset):
             discount_factor=self.hyperparameters['discount_factor'],
             lam=self.hyperparameters['lam'],
             entropy_loss_scaling=self.hyperparameters['entropy_loss_scaling'],
-            writer=writer,
+            logger=logger,
         ))
 
     def test_agent(self):
