@@ -1,16 +1,16 @@
 from .builder import PresetBuilder
 from .preset import Preset
 from all.agents import IndependentMultiagent
-from all.logging import DummyWriter
+from all.logging import DummyLogger
 
 
 class IndependentMultiagentPreset(Preset):
     def __init__(self, name, device, presets):
         super().__init__(name, device, presets)
 
-    def agent(self, writer=DummyWriter(), train_steps=float('inf')):
+    def agent(self, logger=DummyLogger(), train_steps=float('inf')):
         return IndependentMultiagent({
-            agent_id: preset.agent(writer=writer, train_steps=train_steps)
+            agent_id: preset.agent(logger=logger, train_steps=train_steps)
             for agent_id, preset in self.hyperparameters.items()
         })
 
